<template>
  <div class="equity-registration-warehousing  corporate-customers">
    <div class="left-tree" v-show="componentName === 'table'">
      <tree-side :treeData="treeData" :tabList="tabList" :defaultProps="defaultProps" @currentChange="currentChange"
        @tabChange="tabChange" @filterChange="filterChange"></tree-side>
    </div>
    <div class="right-table " v-show="componentName === 'table'">
      <div class="full-page bg">
        <div class="search-box">
          <SuperSearch :searchForm="queryParams" :basisOption="basisOption" @is-show-advance="advanced()"
            @search="handleSearch" ref="superSearch" />
        </div>
        <div class="main-table-container">
          <div class="table-container" style="padding: 20px">
            <div style="margin-bottom: 10px" ref="btnPanel">
              <el-button slot="reference" icon="el-icon-delete" type="success" plain class="btn btn-delete"
                :disabled="this.currentDataDel.length == 0" @click="examineBtn()">
                批量审核
              </el-button>
            </div>
            <div class="table-content" ref="tabelRef">
              <div class="table">
                <el-table stripe v-loading="tableLoading" ref="multipleSelection" :data="tableData" :row-key="getRowKey"
                  :max-height="tableMaxHeight" class="table-list" border @selection-change="handleSelectionChange">
                  <el-table-column type="selection" align="center" :selectable="selectable"></el-table-column>
                  <el-table-column type="index" width="65" label="序号" align="center">
                  </el-table-column>
                  <el-table-column prop="belongsOrgName" show-overflow-tooltip min-width="180" align="center"
                  label="所属公司">
                </el-table-column>
                  <el-table-column prop="name" show-overflow-tooltip min-width="120" align="center" label="资产名称">
                  </el-table-column>
                  <el-table-column prop="code" show-overflow-tooltip min-width="120" align="center" label="资产编号">
                  </el-table-column>
                  <el-table-column prop="assetType" show-overflow-tooltip min-width="120" align="center" label="土地类型">
                    <template v-slot="{ row }">
                      {{ getDictName('tdlx', row.assetType) }}
                    </template>
                  </el-table-column>
                  <el-table-column prop="assetBusiness" show-overflow-tooltip min-width="120" align="center" label="资产业态">
                    <template v-slot="{ row }">
                      {{ getDictName('zcytyt', row.assetBusiness) }}
                    </template>
                  </el-table-column>
                  <el-table-column prop="assetSrc" show-overflow-tooltip min-width="120" align="center" label="资产来源">
                    <template v-slot="{ row }">
                      {{ getDictName('xmly', row.assetSrc) }}
                    </template>
                  </el-table-column>
                  <el-table-column prop="assetNature" show-overflow-tooltip min-width="120" align="center" label="资产属性">
                    <template v-slot="{ row }">
                      {{ getDictName('xmsx', row.assetNature) }}
                    </template>
                  </el-table-column>
                  <el-table-column prop="assetBelong" show-overflow-tooltip min-width="120" align="center" label="资产归属">
                    <template v-slot="{ row }">
                      {{ getDictName('xmgs', row.assetBelong) }}
                    </template>
                  </el-table-column>
                  <el-table-column prop="bookValue" show-overflow-tooltip min-width="130" align="center" label="账面价值(万元)">
                  </el-table-column>
                  <el-table-column prop="landArea" show-overflow-tooltip min-width="130" align="center" label="土地面积(亩)">
                  </el-table-column>
                  <el-table-column prop="assetAudit" show-overflow-tooltip min-width="120" align="center" label="审核状态">
                    <template v-slot="{ row }">
                      <el-tag v-if="row.assetAudit == -1" type="info">
                        {{ getDictName('shzt', row.assetAudit) }}
                      </el-tag>
                      <el-tag v-if="row.assetAudit == 0">
                        {{ getDictName('shzt', row.assetAudit) }}
                      </el-tag>
                      <el-tag v-if="row.assetAudit == 1" type="danger">
                        {{ getDictName('shzt', row.assetAudit) }}
                      </el-tag>
                      <el-tag v-if="row.assetAudit == 2" type="success">
                        {{ getDictName('shzt', row.assetAudit) }}
                      </el-tag>
                    </template>
                  </el-table-column>
                  <el-table-column show-overflow-tooltip min-width="180" align="center" fixed="right" label="操作">
                    <template v-slot="{ row }">
                      <el-link type="primary" :underline="false" style="margin-right: 10px;" @click="detailBtn(row)">
                        详情
                      </el-link>
                      <el-link type="success" :underline="false" style="margin-right: 10px;" @click="examineBtn(row)"
                        v-if="row.assetAudit == 0">
                        审核
                      </el-link>
                      <el-link type="danger" :underline="false" style="margin-right: 10px;" @click="turnDown(row)"
                        v-if="row.assetAudit == 0">
                        驳回
                      </el-link>
                    </template>
                  </el-table-column>
                </el-table>
              </div>
              <pagination ref="paginationPanel" style="margin-top: 10px" :pageResult="queryParams"
                @size-change="handleSizeChange" @current-change="handleCurrentChange" />
            </div>
          </div>
        </div>
      </div>
    </div>
    <!-- 详情 -->
    <detailDialog v-show="componentName === 'detailDialog'" @closeComponent="closeComponent" ref="detailDialog">
    </detailDialog>
  </div>
</template>

<script>
import pagination from '@/components/pagination'
import { TableMixin } from '@/mixins/tableMixin'
import utils from '@/utils.js'
import detailDialog from './components/detailDialog.vue'
import SuperSearch from '@/components/SuperSearch/index.vue'
import treeSide from '@/components/treeSide/index.vue'
import api from '@/api/LandLedger/LandLedgerEnter/LandLedgerInfo.js'
import pubSub from 'pubsub-js'

const portal = window.context.portal
export default {
  name: 'PropertyLedger',
  components: {
    pagination,
    SuperSearch,
    treeSide,
    detailDialog
  },
  mixins: [TableMixin],
  data() {
    return {
      tableMaxHeight: 600,
      loading: false,
      tableLoading: false,
      componentName: 'table',
      defaultProps: {
        children: 'children',
        label: 'name',
      },
      tabList: ['公司'],
      treeData: [],
      tableData: [],
      multipleSelection: [],
      currentDataDel: [],
      queryParams: {
        page: 1,
        pageSize: 20,
        total: 0,
        belongsOrgId: '',
        assetNo:'',
        assetFloor:'',
        assetNature: [],
        assetType: [],
        landStatus: [],
        assetBusiness: [],
      },
      basisOption: [
        {
          itemLabel: '审核状态',
          itemProp: 'assetAudit',
          itemType: 'radio',
          searchType: 'basic',
          labelWidth: '100px',
          option: [
          ]
        },
        {
          itemLabel: '是否获取权属信息',
          itemProp: 'isGetWarrents',
          itemType: 'radio',
          searchType: 'basic',
          labelWidth: '100px',
          option: [
          ]
        },
        {
          itemLabel: '资产属性',
          itemProp: 'assetNature',
          itemType: 'radio',
          searchType: 'basic',
          labelWidth: '100px',
          option: [
          ]
        },

        {
          itemLabel: '土地类型',
          itemProp: 'assetType',
          itemType: 'radio',
          searchType: 'basic',
          labelWidth: '100px',
          option: [
          ]
        },
        {
          itemLabel: '资产状态',
          itemProp: 'landStatus',
          itemType: 'checkbox',
          searchType: 'basic',
          labelWidth: '100px',
          option: [
          ]
        },
        {
          itemLabel: '资产名称',
          itemProp: 'name',
          itemType: 'input',
          labelWidth: '90px',
          searchType: 'advance'
        },
        {
          itemLabel: '资产编号',
          itemProp: 'code',
          itemType: 'input',
          labelWidth: '90px',
          searchType: 'advance'
        },
        {
          itemLabel: '资产业态',
          itemProp: 'assetBusiness',
          itemType: 'select',
          labelWidth: '90px',
          searchType: 'advance',
          option: []
        },


      ],
      sorter: [
        {
          direction: '',
          property: 'matCode'
        },
        {
          direction: 'DESC',
          property: 'createTime'
        }
      ],
      pubSub: null

    }
  },

  created() {
    this.basisOption[0].option = utils.getDictItemsFromCache('shzt').slice(1)
    this.basisOption[1].option = utils.getDictItemsFromCache('sfzwzc')
    this.basisOption[2].option = utils.getDictItemsFromCache('xmsx')
    this.basisOption[3].option = utils.getDictItemsFromCache('tdlx')
    this.basisOption[4].option = utils.getDictItemsFromCache('zczt')
    this.basisOption[6].option = utils.getDictItemsFromCache('zcytyt')
    this.getProject()
    this.getUserOrgTree()
    this.loadData()
  },
  mounted() {
    this.calcTableHeight()
    this.$root.$on('resize', () => {
      this.calcTableHeight(500)
    })
     // 添加自定义面包屑pub-sub
     this.pubSub = pubSub.subscribe('breadcrumb-click', (_, item) => {
      console.log(item)
      if (item.isCurrentRoute) this.componentName = 'table'
    })
  },
  computed: {
    // 加工为后端需要的请求格式
    computedQuery() {
      /*
       * 定义 escapeOpt 字段对应字典名 对象
       *  为重新加工结构赋值的新请求配置参数
       * */
      const querys = [

        { operation: 'IN', property: 'assetAudit', relation: 'AND' },
        { operation: 'IN', property: 'assetNature', relation: 'AND' },
        { operation: 'IN', property: 'landStatus', relation: 'AND' },
        { operation: 'IN', property: 'assetType', relation: 'AND' },
        { operation: 'IN', property: 'isGetWarrents', relation: 'AND' },
        { operation: 'LIKE', property: 'name', relation: 'AND' },
        { operation: 'LIKE', property: 'assetNo', relation: 'AND' },
        { operation: 'EQUAL', property: 'assetFloor', relation: 'AND' },
        { operation: 'EQUAL', property: 'belongsOrgId', relation: 'AND' },
        { operation: 'EQUAL', property: 'assetBusiness', relation: 'AND' },

      ]
      const { pageSize, page, ...item } = this.queryParams
      return {
        pageBean: { pageSize, page },
        querys: querys.flatMap(i => {
          const value = item[i.property]
          if (Array.isArray(value) && !value.length) return []
          if (value === '') return []
          return { group: 'main', ...i, value }
        }),
        sorter: this.sorter.filter(i => i.direction !== '')
      }
    }
  },
  methods: {
    //关闭组件
    closeComponent(row) {
      this.componentName = 'table'
      this.loadData()
    },
    //字典翻译
    getDictName(code, value) {
      return utils.getDictName(code, value)
    },
    //获取组织树
    getUserOrgTree() {
      let curUserDetail = this.$store.state.user.currentUserDetail
      let orgId = curUserDetail.org[0].orgId
      api.getUserOrgTree(orgId, res => {
        if (res) {
          this.treeData = res
        }
      })
    },
    //获取项目下拉
    async getProject() {
      await api.projectQquery({
        pageBean: {
          pageSize: -1,
          page: 1
        }
      }, res => {
        if (res.rows) {
          // this.basisOption[2].option = res.rows.map(i => {
          //   return {
          //     ...i,
          //     name: i.projectName,
          //     value: i.id
          //   }
          // })
          // this.$refs.superSearch && this.$refs.superSearch.dataInitialization(this.queryParams)
        }
      })
    },
    //获取数据
    loadData() {
      this.tableLoading = true
      let params = this.computedQuery
      params.querys.push(
        {
          group: "main",
          operation: "NOT_EQUAL",
          property: "assetAudit",
          relation: "AND",
          value: '-1',
        }
      )
      api.queryData(params, res => {
        if (res.rows) {
          this.tableData = res.rows
          this.queryParams.total = res.total
          this.tableLoading = false
        }
      })
    },
    //判断勾选
    selectable(row, index) {
      if (row.assetAudit !== '0') {
        return false;
      } else {
        return true;
      }
    },

    //左边树节点
    currentChange(value, data) {
      if (value) {
        this.queryParams.belongsOrgId = value.id
      } else {
        this.queryParams.belongsOrgId = ''
      }
      this.loadData()
    },
    //左边树tab
    tabChange() {
    },
    //左边树搜索
    filterChange(val) {
    },
    //添加
    handleAdd() {
      this.componentName = 'editAddDialog'
      pubSub.publish('add-custom-breadcrumb', '添加')

      this.$refs.editAddDialog.addModifyBtn()
    },
    //详情
    detailBtn(row) {
      this.componentName = 'detailDialog'
      pubSub.publish('add-custom-breadcrumb', '详情')

      this.$refs.detailDialog.detail(row)
    },
    // 审核驳回
    examineBtn(row) {
      let ids
      if (row) {
        ids = row.id
      } else {
        ids = this.currentDataDel.join()
      }
      this.$confirm(`确定审核选中数据吗？`, '提示', {
        confirmButtonText: '确认',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        api.examine({
          ids: ids,
          status: 2,
        }, res => {
          if (res.state) {
            this.$message.success(`审核成功`)
            this.loadData()
          }
        })
      })
    },
    //驳回
    turnDown(row) {
      this.$prompt('', '驳回理由', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        inputPattern: /^[^\s][\s\S]*$/,
        inputErrorMessage: '请输入驳回理由'
      }).then(({ value }) => {
        let params = {
          ids: row.id,
          status: 1,
          auditMsg: value
        }
        api.examine(params, res => {
          if (res.state) {
            this.$message.success(`驳回成功`)
            this.loadData()
          }
        })
      }).catch(() => {
      });
    },
    // 顶部搜索
    handleSearch(data) {
      this.queryParams = data
      this.loadData()
    },
    //表格选中
    handleSelectionChange(val) {
      this.currentDataDel = val.map((item) => {
        return item.id
      })
    },
    // 指定一个key标识这一行的数据
    getRowKey(row) {
      return row.id;
    },
    //分页页数
    handleCurrentChange(page) {
      this.queryParams.page = page
      this.loadData()
    },
    //分页大小
    handleSizeChange(pageSize) {
      this.queryParams.pageSize = pageSize
      this.loadData()
    }
  },
  beforeDestroy() {
    // 在组件销毁之前 清除订阅消息
    pubSub.unsubscribe(this.pubSub)
  }
}
</script>

<style lang="scss" scoped>
/deep/ .full-page {
  padding-left: 16px !important;
}

.equity-registration-warehousing {
  width: 100%;
  display: flex;

  .left-tree {
    margin: 16px 0 0 24px;
  }

  .right-table {
    width: calc(100% - 324px);
  }
}

.search-container {
  height: 100px;
}

.search-box {
  //height: 350px;
  padding: 20px 30px;
  transition: all 1s;
  background-color: #ffffff;
  border-radius: 8px;
}

/deep/ .el-table .el-table__header th {
  padding: 12px 0 !important;
  background-color: #f1f5f8 !important;
}

/deep/ .el-table .el-table__header th .cell {
  font-size: 16px;
  color: #545454;
  font-weight: 700;
  font-family: PingFang SC-Medium, PingFang SC;
  white-space: nowrap;
}

.common-tree-container {
  height: calc(100% - 180px);
  margin-top: 0.52083vw;
  padding: 1.04167vw 1.04167vw;
  background-color: #fff;
  position: relative;
  box-sizing: border-box;
  overflow-y: auto;
  border-radius: 20px;
  box-shadow: 0px 0px 0.625vw 0 rgba(92, 102, 83, 0.2);
}

.container-head {
  display: flex;
  align-items: center;

  i {
    font-size: 16px;
    margin-left: 5px;
    font-weight: 600;
    cursor: pointer;
  }
}

.move-tree /deep/ .el-tree {
  height: 90%;
  overflow-y: auto;
  border: none;
}

.cloumn-btn {
  border: 1px solid #2761ff;
  padding: 3px 10px;
  border-radius: 5px;

  &:nth-child(1) {
    margin-right: 5px;
  }

  &:nth-child(2) {
    margin-right: 5px;
  }

  &:nth-child(1):hover {
    background-color: #2761ff;
    color: #fff;
  }

  &:nth-child(2):hover {
    background-color: #2761ff;
    color: #fff;
  }

  // &:nth-child(2):hover {
  //   background-color: #f56c6c;
  //   color: #fff;
  //   border-color: #f56c6c;
  // }
  /deep/ i,
  span {
    font-size: 16px;
  }
}

/deep/ .el-tree-node__content {
  padding: 5px 0;
}
</style>
